@@ -46,7 +46,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "1.8.2",
+    VERSIONNUM       => "1.8.3",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -57,7 +57,8 @@ use constant {
     AUTHKEY_FILENAME => "authkey",
     RA_TMPDIR        => "/var/lib/pgsql/tmp",
     LOCK_FILENAME    => "PGSQL.lock",
-	PID_FILENAME     => "pg-rex_tools.pid"
+    PID_FILENAME     => "pg-rex_tools.pid",
+    PID_FILEDIR      => "/var/run"
 };
 
 our $additional_information_mode = 0;
@@ -458,7 +459,7 @@ sub read_cib{
     chomp $my_node;
 
     # tmpdir のデフォルト値を設定する
-    $cib_value{'tmpdir'} = "/var/lib/pgsql/tmp";
+    $cib_value{'tmpdir'} = RA_TMPDIR;
 
     open (FILE, $cib_path) or printlog("ERROR", COMMON_MS0023, $cib_path);
     @cib_strings = <FILE>;
@@ -1304,7 +1305,7 @@ sub check_dbcluster_access {
 
 
 sub create_pid_file {
-    my $pid_fullname = RA_TMPDIR."/".PID_FILENAME;
+    my $pid_fullname = PID_FILEDIR."/".PID_FILENAME;
     my $pid;
     my $exit_code;
 
@@ -1352,7 +1353,7 @@ sub create_pid_file {
 }
 
 sub unlink_pid_file {
-    my $pid_fullname = RA_TMPDIR."/".PID_FILENAME;
+    my $pid_fullname = PID_FILEDIR."/".PID_FILENAME;
 
     if (!unlink $pid_fullname) {
         printlog("LOG", COMMON_MS0051, PID_FILENAME, $!);
